# Changelog

All notable changes to this project will be documented in this file.

## Unreleased

// Add new changes below this line.

### Added

- Added PyPI version to README.

- Return values from the _safe_delete and _safe_delete_recursively methods for additional testing purposes. Does not impact the original code.


## v0.1.3 (2022-12-04)

### Added

- Updated README on PyPI to show Python versions.

